@@ -15,7 +15,15 @@
 #' @export
 
 govcan_setup <- function(url = "https://open.canada.ca/data/en") {
-  ckanr::ckanr_setup(url = url)
-  msgInfo("ckanr url set to", suppressWarnings(ckanr::ckan_info()$site_url))
-  invisible(url)
+  tryCatch({
+    ckanr::ckanr_setup(url = url)
+    msgInfo("ckanr url set to", suppressWarnings(ckanr::ckan_info()$site_url))
+    invisible(url)
+  },
+  warning = function(e){
+    cli::cli_alert_warning("govcan_setup failed, please set ckanr url manually")
+  },
+  error = function(e){
+    cli::cli_alert_warning("govcan_setup failed, please set ckanr url manually")
+  })
 }
